@@ -8,9 +8,9 @@ use Perinci::Object;
 use Perinci::Sub::Util qw(err);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-03'; # DATE
+our $DATE = '2022-10-09'; # DATE
 our $DIST = 'Perinci-Sub-To-CLIDocData'; # DIST
-our $VERSION = '0.300'; # VERSION
+our $VERSION = '0.301'; # VERSION
 
 our %SPEC;
 
@@ -433,6 +433,7 @@ sub gen_cli_doc_data_from_meta {
         # XXX utilize information from args_rels
 
         require Getopt::Long::Util;
+        require Module::Installed::Tiny;
         my @plain_opts;
         my @pod_opts;
         my %opt_locations; # key=$ARGNAME or "common:$SOMEKEY"
@@ -454,12 +455,12 @@ sub gen_cli_doc_data_from_meta {
             my $copt = defined $ospecmeta->{common_opt} ? $common_opts->{ $ospecmeta->{common_opt} } : undef;
 
             next if defined $ospecmeta->{common_opt} && $copt->{usage};
-            my $caption_from_schema;
+            my ($caption_from_schema, $type, $cset);
             if ($argprop && $argprop->{schema} &&
                     ref $argprop->{schema} eq 'ARRAY' # ignore non-normalized schema for now
                 ) {
-                my $type = $argprop->{schema}[0];
-                my $cset = $argprop->{schema}[1];
+                $type = $argprop->{schema}[0];
+                $cset = $argprop->{schema}[1];
                 if ($type eq 'array') {
                     if ($cset->{of} && ref $cset->{of} eq 'ARRAY') {
                         $caption_from_schema = $cset->{of}[0];
@@ -481,7 +482,12 @@ sub gen_cli_doc_data_from_meta {
                         $argprop ?
                         ($argprop->{'x.cli.opt_value_label'} // $argprop->{caption} // $caption_from_schema) :
                         $copt->{value_label}
-                    ),
+                ),
+                value_label_link=>(
+                    $ospecmeta->{is_json} ? undef :
+                    $ospecmeta->{is_yaml} ? undef :
+                    defined($type) && Module::Installed::Tiny::module_installed("Sah::Schema::$type") ? "Sah::Schema::$type" : undef
+                ),
             }, $ospec);
             my $plain_opt = $hres->{plaintext};
             my $pod_opt   = $hres->{pod};
@@ -592,7 +598,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.300 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2022-06-03.
+This document describes version 0.301 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2022-10-09.
 
 =head1 SYNOPSIS
 
@@ -841,9 +847,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
